@@ -9,11 +9,7 @@
 #include <QDebug>
 #include <QFileDialog>
 
-//check your last post. Also exc and wer. Think it might be problems relating to writing to .tmpvid. Running stream on root priveleges might solve it, but I dont want toresort to that yet.
-//File: Working: Yoooutube.mp4, Y.Tu.mama.avi, USAbit.avi,   La Luna.avi, vids taken by camera (slowly for large vids).
-//Not: Yeah Yeah.mp4, U2.mp4, The Tron Rap.mp4, Gorrilaz, The dreamers.AVI?, the Matrix.avi,
-//VLC now working, but I had to delete my cache and config. Kind of works.
-//Old VLC method seems to work.
+//12-July-2011 - Issues with SPYCAM - it has to send raw image over network so if signal is crap - you get choppy image. Might need to do generating Xvid file.
 
 MainWindow::MainWindow(QWidget *parent) :
     QMainWindow(parent),
@@ -24,6 +20,7 @@ MainWindow::MainWindow(QWidget *parent) :
     //cambackyes=false;
     ui->setupUi(this);
     debugclicked = false;
+    vlcsdpgenerated = "";
     ui->labcust->hide();
     ui->custom1->hide();
     ui->outWind->hide();
@@ -54,7 +51,7 @@ MainWindow::~MainWindow()
 }
 
 void MainWindow::makeStream(QString host, bool backcamera, bool video, QString port, QString width, QString height, int outp){
-    QString contextRun;
+    QString contextRun; QString messager;
     QString begbits;
     QString midbits;
     QString streamout;
@@ -76,20 +73,20 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
             notify("streaming to "+filelocation, false);
         }
         else if(outp==0){//http  //dont forget to delete file
+            /////////////////////DOOOOOOOOOOOSOMMMEEEEEEEEEEETTTTTTHHHHHHHHIIIIIIIIINGGGGGGGGGGGGGGGGGGGGGGGGGGggg///////////////////
             QString exc = "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid > /dev/null\nmkfifo /home/user/.tmpvid\ngst-launch-0.10vlc  "+begbits+"ffmpegcolorspace ! jpegenc"+Jquality+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid";
             //QString wer = "#!/bin/bash\nread throwaway\nsleep 5\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: video/x-msvideo\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmmm >/dev/null\nmkfifo /home/user/.tmmm\ngst-launch "+begbits+" ffmpegcolorspace ! jpegenc "+Jquality+" ! filesink location=/home/user/.tmmm >/dev/null &\ncat /home/user/.tmmm";
             write2file("/home/user/.httpstream", exc);
             executable("/home/user/.httpstream");
-            qDebug() << exc;
             streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream";
-            notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
+            messager = "Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port;
             notify("streaming", false);
         }
 
         else if(outp!=0 || outp!=4){ //http or filesink? no   //this is neccasary because http and localfile dont streamout normally
             if(outp==1){ //VLC
                 midbits = "dsph264enc ! rtph264pay ! udpsink";
-                contextRun = "   Open n900mediastrm.sdp file in VLC";
+                contextRun = "   Open n900videostrm.sdp file in VLC";
             } else if (outp==2){ //Xout
                 midbits = "ffmpegcolorspace ! jpegenc "+Jquality+" ! tcpserversink";
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900Xvideo.sh'";
@@ -102,25 +99,19 @@ void MainWindow::makeStream(QString host, bool backcamera, bool video, QString p
                 contextRun = "   from terminal, run: 'sh ~/Desktop/n900FileSave.sh'\n(Make sure that 'gstreamer0.10-ffmpeg' is installed on remote PC)";
             }
             streamout = "gst-launch-0.10 "+begbits+midbits+" host="+host+" port="+port;
-            notify("Run file on Remote PC: \n"+contextRun, true);
-            //more contextual instruction o how to run the file needed.
-            notify("streaming", false);
-
+            messager = "Run file on Remote PC: \n"+contextRun;
         }
     }
     else if (!video){
         streamout = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay ! udpsink host="+host+" port="+port;
-        /*QString stream1 = "gst-launch-0.10 pulsesrc ! audioconvert ! volume volume="+ui->vol->text()+" ! audioresample ! nokiaaacenc ! rtpmp4apay";
-        write2file("/home/user/.httpstream", "#!/bin/bash\nread throwaway\nsleep 7\necho HTTP/1.0 200 Ok\necho Server: socat kludge\necho -n Date:\ndate\necho Content-Type: audio/mpeg\necho Content-Length: 10000000\necho Last-Modified: Sun, 19 Jun 2011 22:53:20 GMT\necho Connection: close\necho\nrm -f /home/user/.tmpvid 2>/dev/null\nmkfifo /home/user/.tmpvid\n"+stream1+" ! filesink location=/home/user/.tmpvid >/dev/null &\ncat /home/user/.tmpvid");
-        executable("/home/user/.httpstream");
-        streamout = "socat TCP4-LISTEN:"+port+",reuseaddr,fork exec:/home/user/.httpstream",
-        notify("Open VLC:\nMedia-->Open Network Stream..., Type in:\nhttp://"+getIP()+":"+port, true);
-        notify("streaming", false);*/
+        contextRun = "   Open n900audiostrm.sdp file in VLC";
+        messager = "Run file on Remote PC: \n"+contextRun;
 
     }
+    notify(messager, true);
+    notify("streaming", false);
     ui->outWind->setText("...currently streaming...");
     QProcess*proc = new QProcess();
-    qDebug() << streamout;
     proc->start(streamout);
     //ui->outWind->append(proc->readAll()); //NOW JUST NEED TO PASS OUTPUT FROM GST-LAUNCH BACK INTO OUTWIND
  }
@@ -152,9 +143,21 @@ void MainWindow::on_streambut_clicked()
         notify("Fill out filename first", false);
     }
     else{
-        if((cind!=0 )&& (!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){   //if not http or file hasnt been generated previously, then flag.
+        if((cind==1) || ui->type1->currentIndex()==1){  //VLC (audio or Vid)
+            ui->vidsink->setCurrentIndex(1); //set it to VLC (so http is never on)
+            qDebug() << "is VLC";
+            if(vlcsdpgenerated==ui->address1->text()+" "+ui->type1->currentText()){
+                qDebug() << "and is also generated";
+                helper();
+            }
+            else {
+                vlcsdpgenerated = "";
+                notify("Please generate a new SDP file", false);
+            }
+        }
+        else if(cind!=0 && (!alreadygen.contains(ui->vidsink->currentText()+" "+ui->address1->text()+":"+ui->port1->text()))){   //if not http and the file hasnt been generated previously, then flag.
             sdpgenerated = false;
-            if(ui->type1->currentIndex()!=1 && cind!=4){ //if not audio and not filesink
+            if(cind!=4){ // and not filesink
                 notify("Please generate and send a new file, then stream", false);
             }
             else { //local file streams
@@ -217,7 +220,7 @@ void MainWindow::applySettings(){
 }
 
 void MainWindow::streamProcess1(){
-    if(videoyes){
+    //if(videoyes){
         hostname = ui->address1->text();
         portnum = ui->port1->text();
         //getting the size
@@ -237,10 +240,10 @@ void MainWindow::streamProcess1(){
         if(!fileyes)ledON(true);
 
         makeStream(hostname,cambackyes,videoyes,portnum,widthnum,heightnum, currOutput);
-    }
-    else if(!videoyes){
-        notify("feature temporarily disabled for this update.", false);
-    }
+    /*}
+    else if(!videoyes){*/
+
+    //}
 }
 
 void MainWindow::showWin(bool hid){
@@ -379,9 +382,7 @@ void MainWindow::on_type1_activated(int index) //link on cmera1_activated into t
         ui->labfilenam->hide();
         ui->filesinkname->hide();
 
-        ui->scpbutton->hide();
-        ui->sdpgen->hide();
-
+        vidoutput = "VLC sdp";
         videoyes = false;
     }
     else { //Video
@@ -454,7 +455,7 @@ void MainWindow::on_debuginfo_clicked()
         ui->sdpgen->hide();
         ui->scpbutton->hide();
         debugclicked=false;
-    }else{
+    } else {
         ui->outWind->show();
         ui->sdpgen->show();
         on_vidsink_activated(ui->vidsink->currentIndex()); //to prevent
@@ -483,8 +484,8 @@ void MainWindow::on_sdpgen_clicked()
     QString decoder;QString typer;
     int outpp = ui->vidsink->currentIndex();
 
-    if(outpp==0){ //VLC Http   <------Needs hiding
-        notify("Don't need to generate anything for this", false);
+    if(outpp==0){ //Http   <------Needs hiding
+        notify("Don't need to generate anything for this", false); //Need to get rid of....
         ui->outWind->clear();
     }
     else if(outpp==1){ //VLC old
@@ -492,6 +493,8 @@ void MainWindow::on_sdpgen_clicked()
         else if(!videoyes){ typer="audio"; decoder="MP4A-LATM/48000/2";}
         currentFile ="/home/user/MyDocs/n900"+typer+"strm.sdp";
         write2file(currentFile,"v=0\nm="+typer+" "+ui->port1->text()+" RTP/AVP 96\nc=IN IP4 "+localip+"\na=rtpmap:96 "+decoder); //VLC
+        ui->outWind->append("Generated file at: "+currentFile);
+        vlcsdpgenerated = ui->address1->text()+" "+ui->type1->currentText(); //generated, but doesnt need to be sent via scp (for windows) (it's checked against current ip @stream to see if it needs to be regenerated)
     }
 
     else if(outpp==2) { //Xout
@@ -504,6 +507,7 @@ void MainWindow::on_sdpgen_clicked()
         //write2file(currentFile,"gst-launch-0.10 udpsrc port="+ui->port1->text()+" ! smokedec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0");  //webcam
         //Using Jpeg for now, higer quality?
         write2file(currentFile,"gst-launch-0.10 tcpclientsrc host="+localip+" port="+ui->port1->text()+"  ! jpegdec ! ffmpegcolorspace ! v4l2loopback device=/dev/video0"); //Xout
+        notify("Please make sure that v42l2loopback module is installed on your PC", true);
         ui->outWind->append("Generated file at: "+currentFile);
 
     }
@@ -595,51 +599,54 @@ void MainWindow::on_scpsend_clicked()
 
 void MainWindow::on_vidsink_activated(int index)  //First part is for showing the filename widgets
 {
-    if(ui->camera1->itemText(2)!="File"){
-        ui->camera1->addItem("File");
+    if(ui->camera1->itemText(2)!="File (experimental)"){
+        ui->camera1->addItem("File (experimental)");
     }
-    if(index==4 || index==5){//File
-        ui->labfilenam->show();
-        ui->filesinkname->show();
-        ui->tickqual->show();
-        if(index==4){ //local
-            ui->sdpgen->hide();
-            ui->scpbutton->hide();
-            ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
-            //Hide top row
-            ui->address1->hide(); ui->labAddr->hide(); ui->port1->hide(); ui->labPort->hide();
-            ui->outWind->setText("Nothing needed to generate or send. \nPlease fill out name of video and hit Stream.");
-            sdpgenerated = true; //doesnt need to generate one.
-            ui->camera1->removeItem(2); //<=========== Doesn't use file as source.////////
-            ui->labsize->show(); ui->size1->show();
-        }
-        if(index==5) {
-            if(debugclicked){ui->sdpgen->show();}  //error when switching from local file to remote file.
-            ui->labfilenam->setText("    Remote Filename:");
-            vidoutput="RemoteFilescript";
-            ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
-            ui->outWind->setText("Fill out filename and then generate");
-        }
-
-    } else if(index!=4 || index!=5){
-
-        ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
-        ui->labfilenam->hide();
-        ui->filesinkname->hide();
-        if(debugclicked){ui->sdpgen->show();}// stops it appearing when showdebug hasnt been clicked yet
-        if(index==0){
-            ui->sdpgen->hide();
-            ui->scpbutton->hide();
-            ui->outWind->setText("Nothing needed to generate or send. \nPlease hit Stream.");
-            sdpgenerated = true; //doesnt need to generate one.
-        } else {
-            ui->outWind->setText("Please generate and send");
+    if(ui->type1->currentIndex()!=1){
+        if(index==4 || index==5){//File
+            ui->labfilenam->show();
+            ui->filesinkname->show();
             ui->tickqual->show();
-            if(index==1){vidoutput = "VLC sdp";}
-            if(index==2){vidoutput = "Xscript";}
-            if(index==3){vidoutput="Webscript";}
+            if(index==4){ //local
+                ui->sdpgen->hide();
+                ui->scpbutton->hide();
+                ui->labfilenam->setText("     Filename (/home/user/MyDocs/.videos/):");
+                //Hide top row
+                ui->address1->hide(); ui->labAddr->hide(); ui->port1->hide(); ui->labPort->hide();
+                ui->outWind->setText("Nothing needed to generate or send. \nPlease fill out name of video and hit Stream.");
+                sdpgenerated = true; //doesnt need to generate one.
+                ui->camera1->removeItem(2); //<=========== Doesn't use file as source.////////
+                ui->labsize->show(); ui->size1->show();
+            }
+            if(index==5) {
+                if(debugclicked){ui->sdpgen->show();}  //error when switching from local file to remote file.
+                ui->labfilenam->setText("    Remote Filename:");
+                vidoutput="RemoteFilescript";
+                ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
+                ui->outWind->setText("Fill out filename and then generate");
+            }
+        } else if(index!=4 || index!=5){
+            ui->address1->show(); ui->labAddr->show(); ui->port1->show(); ui->labPort->show();
+            ui->labfilenam->hide();
+            ui->filesinkname->hide();
+            if(debugclicked){ui->sdpgen->show();}// stops it appearing when showdebug hasnt been clicked yet
+            if(index==0){
+                ui->sdpgen->hide();
+                ui->scpbutton->hide();
+                ui->outWind->setText("Nothing needed to generate or send. \nPlease hit Stream.");
+                sdpgenerated = true; //doesnt need to generate one.
+            } else {
+                ui->outWind->setText("Please generate and send");
+                ui->tickqual->show();
+                if(index==1){vidoutput = "VLC sdp";}
+                if(index==2){vidoutput = "Xscript";}
+                if(index==3){vidoutput="Webscript";}
+            }
         }
     }
+    else if(ui->type1->currentIndex()==1){ //audio
+        vidoutput = "VLC sdp";
+    }
     ui->sdpgen->setText("Generate "+vidoutput+" file");
     ui->scpbutton->setText("Send "+vidoutput+" to Linux PC");
 }
@@ -649,7 +656,7 @@ Fix script for front camera + LED shutdown on some devices. ??
 Fix IP address issues
 Add zooming feature
 Ncurses version
-Stream to the web as watchdog --using damion's scripts.
+Stream to the web as http --using damion's scripts.
 Add dialog to check whether lens cap still open when exiting.
 Catch error of no filename for File and remotefile before sending.
 Perhaps use sdpyes to check whether file has already been generated, and throw error if address has been changed or something.
